summaryrefslogtreecommitdiffstats
path: root/core/config/project_settings.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'core/config/project_settings.cpp')
-rw-r--r--core/config/project_settings.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/core/config/project_settings.cpp b/core/config/project_settings.cpp
index 9fe54e57a7..9ae6417db5 100644
--- a/core/config/project_settings.cpp
+++ b/core/config/project_settings.cpp
@@ -74,7 +74,7 @@ String ProjectSettings::get_imported_files_path() const {
}
#ifdef TOOLS_ENABLED
// Returns the features that a project must have when opened with this build of Godot.
// This is used by the project manager to provide the initial_settings for config/features.
const PackedStringArray ProjectSettings::get_required_features() {
PackedStringArray features;
@@ -85,7 +85,7 @@ const PackedStringArray ProjectSettings::get_required_features() {
return features;
}
// Returns the features supported by this build of Godot. Includes all required features.
const PackedStringArray ProjectSettings::_get_supported_features() {
PackedStringArray features = get_required_features();
#ifdef MODULE_MONO_ENABLED
@@ -108,7 +108,7 @@ const PackedStringArray ProjectSettings::_get_supported_features() {
return features;
}
// Returns the features that this project needs but this build of Godot lacks.
const PackedStringArray ProjectSettings::get_unsupported_features(const PackedStringArray &p_project_features) {
PackedStringArray unsupported_features;
PackedStringArray supported_features = singleton->_get_supported_features();
@@ -125,7 +125,7 @@ const PackedStringArray ProjectSettings::get_unsupported_features(const PackedSt
return unsupported_features;
}
// Returns the features that both this project has and this build of Godot has, ensuring required features exist.
const PackedStringArray ProjectSettings::_trim_to_supported_features(const PackedStringArray &p_project_features) {
// Remove unsupported features if present.
PackedStringArray features = PackedStringArray(p_project_features);
@@ -569,7 +569,7 @@ Error ProjectSettings::_setup(const String &p_path, const String &p_main_pack, b
bool found = _load_resource_pack(exec_path);
// Attempt with exec_name.pck.
// (This is the usual case when distributing a Godot game.)
String exec_dir = exec_path.get_base_dir();
String exec_filename = exec_path.get_file();
String exec_basename = exec_filename.get_basename();
@@ -1409,7 +1409,7 @@ void ProjectSettings::_add_builtin_input_map() {
ProjectSettings::ProjectSettings() {
// Initialization of engine variables should be done in the setup() method,
// so that the values can be overridden from project.godot or project.binary.
CRASH_COND_MSG(singleton != nullptr, "Instantiating a new ProjectSettings singleton is not supported.");
singleton = this;
@@ -1512,7 +1512,7 @@ ProjectSettings::ProjectSettings() {
GLOBAL_DEF("debug/settings/crash_handler/message",
String("Please include this when reporting the bug to the project developer."));
GLOBAL_DEF("debug/settings/crash_handler/message.editor",
- String("Please include this when reporting the bug on: https://github.com/godotengine/godot/issues"));
+ String("Please include this when reporting the bug on: https://github.com/Redot-Engine/redot-engine/issues"));
GLOBAL_DEF_RST(PropertyInfo(Variant::INT, "rendering/occlusion_culling/bvh_build_quality", PROPERTY_HINT_ENUM, "Low,Medium,High"), 2);
GLOBAL_DEF_RST("rendering/occlusion_culling/jitter_projection", true);
@@ -74,7 +74,7 @@ String ProjectSettings::get_imported_files_path() const {
}
#ifdef TOOLS_ENABLED
-// Returns the features that a project must have when opened with this build of Godot.
+// Returns the features that a project must have when opened with this build of Redot.
// This is used by the project manager to provide the initial_settings for config/features.
const PackedStringArray ProjectSettings::get_required_features() {
@@ -85,7 +85,7 @@ const PackedStringArray ProjectSettings::get_required_features() {
return features;
}
-// Returns the features supported by this build of Godot. Includes all required features.
+// Returns the features supported by this build of Redot. Includes all required features.
const PackedStringArray ProjectSettings::_get_supported_features() {
PackedStringArray features = get_required_features();
@@ -108,7 +108,7 @@ const PackedStringArray ProjectSettings::_get_supported_features() {
return features;
}
-// Returns the features that this project needs but this build of Godot lacks.
+// Returns the features that this project needs but this build of Redot lacks.
const PackedStringArray ProjectSettings::get_unsupported_features(const PackedStringArray &p_project_features) {
PackedStringArray unsupported_features;
@@ -125,7 +125,7 @@ const PackedStringArray ProjectSettings::get_unsupported_features(const PackedSt
return unsupported_features;
}
-// Returns the features that both this project has and this build of Godot has, ensuring required features exist.
+// Returns the features that both this project has and this build of Redot has, ensuring required features exist.
const PackedStringArray ProjectSettings::_trim_to_supported_features(const PackedStringArray &p_project_features) {
// Remove unsupported features if present.
@@ -569,7 +569,7 @@ Error ProjectSettings::_setup(const String &p_path, const String &p_main_pack, b
bool found = _load_resource_pack(exec_path);
// Attempt with exec_name.pck.
- // (This is the usual case when distributing a Godot game.)
+ // (This is the usual case when distributing a Redot game.)
String exec_dir = exec_path.get_base_dir();
String exec_filename = exec_path.get_file();
@@ -1409,7 +1409,7 @@ void ProjectSettings::_add_builtin_input_map() {
ProjectSettings::ProjectSettings() {
// Initialization of engine variables should be done in the setup() method,
- // so that the values can be overridden from project.godot or project.binary.
+ // so that the values can be overridden from project.redot or project.binary.
CRASH_COND_MSG(singleton != nullptr, "Instantiating a new ProjectSettings singleton is not supported.");
singleton = this;